.. _changelog:

===========================
Changes in Jupyter Protocol
===========================

0.1.0
-----

- Initial experimental implementation.


Note: Because the code in this repository originated from jupyter_client you may 
also want to look at its `changelog history <https://jupyter-client.readthedocs.io/en/latest/changelog.html>`_.
